==> mdm-rpc-0.1.11-sources.jar: com/chinayanghe/msp/mdm/vo/position/PositionAreaVo.java <==
package com.chinayanghe.msp.mdm.vo.position;

import java.util.Date;

/**
 * Created by Administrator on 2017/5/16 0016.
 */
public class PositionAreaVo {
    //主键
    private String id;
    //岗位编码
    private String positionCode;
    //省
    private String provinceCode;
    //市
    private String cityCode;
    //县区
    private String countryCode;
    //镇
    private String townCode;
    //有效开始时间
    private Date validStartDate;
    //有效结束时间
    private Date validEndDate;
    //启用状态：0-启用，1-不启用
    private int enableStatus;
    //创建时间
    private Date createDate;
    //创建人
    private String createName;
    //岗位ID
    private String positionId;
    //区域编码
    private String regionCode;
    //区域描述
    private String regionaName;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getPositionCode() {
        return positionCode;
    }

    public void setPositionCode(String positionCode) {
        this.positionCode = positionCode;
    }

    public String getProvinceCode() {
        return provinceCode;
    }

    public void setProvinceCode(String provinceCode) {
        this.provinceCode = provinceCode;
    }

    public String getCityCode() {
        return cityCode;
    }

    public void setCityCode(String cityCode) {
        this.cityCode = cityCode;
    }

    public String getCountryCode() {
        return countryCode;
    }

    public void setCountryCode(String countryCode) {
        this.countryCode = countryCode;
    }

    public String getTownCode() {
        return townCode;
    }

    public void setTownCode(String townCode) {
        this.townCode = townCode;
    }

    public Date getValidStartDate() {
        return validStartDate;
    }

    public void setValidStartDate(Date validStartDate) {
        this.validStartDate = validStartDate;
    }

    public Date getValidEndDate() {
        return validEndDate;
    }

    public void setValidEndDate(Date validEndDate) {
        this.validEndDate = validEndDate;
    }

    public int getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(int enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public String getPositionId() {
        return positionId;
    }

    public void setPositionId(String positionId) {
        this.positionId = positionId;
    }

}

==> mdm-rpc-0.1.90-sources.jar: com/chinayanghe/msp/mdm/vo/position/PositionAreaVo.java <==
package com.chinayanghe.msp.mdm.vo.position;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by Administrator on 2017/5/16 0016.
 */
public class PositionAreaVo implements Serializable {
    private static final long serialVersionUID = -8123903094014997172L;
    //主键
    private String id;
    //岗位编码
    private String positionCode;
    //省
    private String provinceCode;
    //市
    private String cityCode;
    //县区
    private String countryCode;
    //镇
    private String townCode;
    //有效开始时间
    private Date validStartDate;
    //有效结束时间
    private Date validEndDate;
    //启用状态：0-启用，1-不启用
    private int enableStatus;
    //创建时间
    private Date createDate;
    //创建人
    private String createName;
    //岗位ID
    private String positionId;
    //区域编码
    private String regionCode;
    //区域描述
    private String regionaName;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getPositionCode() {
        return positionCode;
    }

    public void setPositionCode(String positionCode) {
        this.positionCode = positionCode;
    }

    public String getProvinceCode() {
        return provinceCode;
    }

    public void setProvinceCode(String provinceCode) {
        this.provinceCode = provinceCode;
    }

    public String getCityCode() {
        return cityCode;
    }

    public void setCityCode(String cityCode) {
        this.cityCode = cityCode;
    }

    public String getCountryCode() {
        return countryCode;
    }

    public void setCountryCode(String countryCode) {
        this.countryCode = countryCode;
    }

    public String getTownCode() {
        return townCode;
    }

    public void setTownCode(String townCode) {
        this.townCode = townCode;
    }

    public Date getValidStartDate() {
        return validStartDate;
    }

    public void setValidStartDate(Date validStartDate) {
        this.validStartDate = validStartDate;
    }

    public Date getValidEndDate() {
        return validEndDate;
    }

    public void setValidEndDate(Date validEndDate) {
        this.validEndDate = validEndDate;
    }

    public int getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(int enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public String getPositionId() {
        return positionId;
    }

    public void setPositionId(String positionId) {
        this.positionId = positionId;
    }

}
